@@ -30,7 +30,7 @@
 #' * `browse_github_pulls()`: Visits the GitHub Pull Request index or one
 #'   specific pull request.
 #' * `browse_travis()`: Visits the project's page on
-#'   [Travis CI](https://travis-ci.com).
+#'   [Travis CI](https://www.travis-ci.com/).
 #' * `browse_circleci()`: Visits the project's page on
 #'   [Circle CI](https://circleci.com).
 #' * `browse_cran()`: Visits the package on CRAN, via the canonical URL.
@@ -60,7 +60,7 @@ NULL
 browse_package <- function(package = NULL) {
   stopifnot(is.null(package) || is_string(package))
   if (is.null(package)) {
-    check_for_project()
+    check_is_project()
   }
 
   urls <- character()
@@ -170,7 +170,7 @@ github_url <- function(package = NULL) {
   stopifnot(is.null(package) || is_string(package))
 
   if (is.null(package)) {
-    check_for_project()
+    check_is_project()
     url <- github_url_from_git_remotes()
     if (!is.null(url)) {
       return(url)
@@ -264,11 +264,3 @@ desc_urls <- function(package = NULL, include_cran = FALSE, desc = NULL) {
   dat$is_github <- !is.na(dat$.match) & grepl("github", dat$host)
   dat[c("url", "desc_field", "is_github")]
 }
-
-check_for_project <- function() {
-  if (!possibly_in_proj()) {
-    ui_stop("
-      We do not appear to be inside a valid project or package
-      No way to discover URLs")
-  }
-}
