@@ -19,13 +19,20 @@
 #' * Provides the markdown to insert a badge into your README
 #'
 #' @name github_actions
+
 #' @param name For `use_github_action()`: Name of one of the example workflows
-#'   from <https://github.com/r-lib/actions/tree/v1/examples>, with or without a
-#'   `.yaml` extension, e.g. "pkgdown" or "test-coverage.yaml".
+#'   from <https://github.com/r-lib/actions/tree/v2/examples>. Examples:
+#'   "pkgdown", "check-standard.yaml".
 #'
-#'   For `use_github_actions_badge()`: Specifies the workflow whose status the
-#'   badge will report. Usually, this is the `name` keyword that appears in the
-#'   workflow `.yaml` file.
+#'   For `use_github_actions_badge()`: Name of the workflow's YAML configuration
+#'   file. Examples: "R-CMD-check", "R-CMD-check.yaml".
+#'
+#'   If `name` has no extension, we assume it's `.yaml`.
+#' @param ref Desired Git reference, usually the name of a tag (`"v2"`) or
+#'   branch (`"main"`). Other possibilities include a commit SHA (`"d1c516d"`)
+#'   or `"HEAD"` (meaning "tip of remote's default branch"). If not specified,
+#'   defaults to the latest published release of `r-lib/actions`
+#'   (<https://github.com/r-lib/actions/releases>).
 #' @eval param_repo_spec()
 #' @param url The full URL to a `.yaml` file on GitHub.
 #' @param save_as Name of the local workflow file. Defaults to `name` or
@@ -36,10 +43,12 @@
 #'   about the workflow. Ignored when `url` is `NULL`.
 #' @inheritParams use_template
 #'
+
 #' @seealso
 #' * [use_github_file()] for more about `url` format and parsing.
 #' * [use_tidy_github_actions()] for the standard GitHub Actions used for
 #'   tidyverse packages.
+
 #' @examples
 #' \dontrun{
 #' use_github_actions()
@@ -67,29 +76,17 @@ use_github_actions <- function() {
 #' documented here.
 #' @export
 #' @rdname github_actions
-use_github_actions_badge <- function(name = "R-CMD-check", repo_spec = NULL) {
+use_github_actions_badge <- function(name = "R-CMD-check.yaml",
+                                     repo_spec = NULL) {
+  if (path_ext(name) == "") {
+    name <- path_ext_set(name, "yaml")
+  }
   repo_spec <- repo_spec %||% target_repo_spec()
   enc_name <- utils::URLencode(name)
-  img <- glue("https://github.com/{repo_spec}/workflows/{enc_name}/badge.svg")
-  url <- glue("https://github.com/{repo_spec}/actions")
+  img <- glue("https://github.com/{repo_spec}/actions/workflows/{enc_name}/badge.svg")
+  url <- glue("https://github.com/{repo_spec}/actions/workflows/{enc_name}")
 
-  use_badge(name, url, img)
-}
-
-uses_github_actions <- function() {
-  path <- proj_path(".github", "workflows")
-  file_exists(path)
-}
-
-check_uses_github_actions <- function() {
-  if (uses_github_actions()) {
-    return(invisible())
-  }
-
-  ui_stop("
-    Cannot detect that package {ui_value(project_name())} already \\
-    uses GitHub Actions.
-    Do you need to run {ui_code('use_github_actions()')}?")
+  use_badge(path_ext_remove(name), url, img)
 }
 
 # individual actions -----------------------------------------------------------
@@ -98,7 +95,7 @@ check_uses_github_actions <- function() {
 #' Configures an individual, specific [GitHub
 #' Actions](https://github.com/features/actions) workflow, either one of the
 #' examples from
-#' [r-lib/actions/examples](https://github.com/r-lib/actions/tree/v1/examples)
+#' [r-lib/actions/examples](https://github.com/r-lib/actions/tree/v2/examples)
 #' or a custom workflow given by the `url` parameter.
 #'
 #' Used internally to power all the other GitHub Actions functions, but it can
@@ -106,6 +103,7 @@ check_uses_github_actions <- function() {
 #' @export
 #' @rdname github_actions
 use_github_action <- function(name,
+                              ref = NULL,
                               url = NULL,
                               save_as = NULL,
                               readme = NULL,
@@ -113,11 +111,19 @@ use_github_action <- function(name,
                               open = FALSE) {
   if (is.null(url)) {
     check_string(name)
-    name <- path_ext_set(name, "yaml")
+    maybe_string(ref)
+
+    if (path_ext(name) == "") {
+      name <- path_ext_set(name, "yaml")
+    }
+
+    ref <- ref %||% latest_release()
     url <- glue(
-      "https://raw.githubusercontent.com/r-lib/actions/v1/examples/{name}"
+      "https://raw.githubusercontent.com/r-lib/actions/{ref}/examples/{name}"
+    )
+    readme <- glue(
+      "https://github.com/r-lib/actions/blob/{ref}/examples/README.md"
     )
-    readme <- "https://github.com/r-lib/actions/blob/v1/examples/README.md"
   } else {
     check_string(url)
     maybe_string(readme)
@@ -133,8 +139,14 @@ use_github_action <- function(name,
   save_as <- path(".github", "workflows", save_as)
   create_directory(path_dir(proj_path(save_as)))
 
-  # `ignore = FALSE` because we took care of this at directory level, above
-  new <- use_github_file(url, save_as = save_as, ignore = FALSE, open = open)
+  if (grepl("^http", url)) {
+    # `ignore = FALSE` because we took care of this at directory level, above
+    new <- use_github_file(url, save_as = save_as, ignore = FALSE, open = open)
+  } else {
+    # local file case, https://github.com/r-lib/usethis/issues/1548
+    contents <- read_utf8(url)
+    new <- write_over(proj_path(save_as), contents)
+  }
 
   if (!is.null(readme)) {
     ui_todo("Learn more at <{readme}>.")
@@ -150,15 +162,17 @@ use_github_action <- function(name,
 #' @export
 #' @rdname github_actions
 use_github_action_check_release <- function(save_as = "R-CMD-check.yaml",
+                                            ref = NULL,
                                             ignore = TRUE,
                                             open = FALSE) {
   use_github_action(
     "check-release.yaml",
+    ref = ref,
     save_as = save_as,
     ignore = ignore,
     open = open
   )
-  use_github_actions_badge("R-CMD-check")
+  use_github_actions_badge(save_as)
 }
 
 #' @section `use_github_action_check_standard()`:
@@ -170,15 +184,17 @@ use_github_action_check_release <- function(save_as = "R-CMD-check.yaml",
 #' @export
 #' @rdname github_actions
 use_github_action_check_standard <- function(save_as = "R-CMD-check.yaml",
+                                             ref = NULL,
                                              ignore = TRUE,
                                              open = FALSE) {
   use_github_action(
     "check-standard.yaml",
+    ref = ref,
     save_as = save_as,
     ignore = ignore,
     open = open
   )
-  use_github_actions_badge("R-CMD-check")
+  use_github_actions_badge(save_as)
 }
 
 #' @section `use_github_action_pr_commands()`:
@@ -189,10 +205,12 @@ use_github_action_check_standard <- function(save_as = "R-CMD-check.yaml",
 #' @export
 #' @rdname github_actions
 use_github_action_pr_commands <- function(save_as = "pr-commands.yaml",
+                                          ref = NULL,
                                           ignore = TRUE,
                                           open = FALSE) {
   use_github_action(
     "pr-commands.yaml",
+    ref = ref,
     save_as = save_as,
     ignore = ignore,
     open = open
@@ -220,7 +238,8 @@ use_github_action_pr_commands <- function(save_as = "pr-commands.yaml",
 #'     [use_github_action_check_standard()].
 #' @export
 #' @rdname tidyverse
-use_tidy_github_actions <- function() {
+#' @inheritParams github_actions
+use_tidy_github_actions <- function(ref = NULL) {
   repo_spec <- target_repo_spec()
 
   use_coverage(repo_spec = repo_spec)
@@ -228,12 +247,16 @@ use_tidy_github_actions <- function() {
   # we killed use_github_action_check_full() because too many people were using
   # it who are better served by something less over-the-top
   # now we inline it here
-  full_status <- use_github_action("check-full.yaml", save_as = "R-CMD-check.yaml")
-  use_github_actions_badge("R-CMD-check", repo_spec = repo_spec)
+  full_status <- use_github_action(
+    "check-full.yaml",
+    ref = ref,
+    save_as = "R-CMD-check.yaml"
+  )
+  use_github_actions_badge("R-CMD-check.yaml", repo_spec = repo_spec)
 
-  pr_status <- use_github_action_pr_commands()
-  pkgdown_status <- use_github_action("pkgdown")
-  test_coverage_status <- use_github_action("test-coverage")
+  pr_status <- use_github_action_pr_commands(ref = ref)
+  pkgdown_status <- use_github_action("pkgdown", ref = ref)
+  test_coverage_status <- use_github_action("test-coverage", ref = ref)
 
   old_configs <- proj_path(c(".travis.yml", "appveyor.yml"))
   has_appveyor_travis <- file_exists(old_configs)
@@ -249,3 +272,47 @@ use_tidy_github_actions <- function() {
 
   invisible(full_status && pr_status && pkgdown_status && test_coverage_status)
 }
+
+# GHA helpers ------------------------------------------------------------------
+
+uses_github_actions <- function() {
+  path <- proj_path(".github", "workflows")
+  file_exists(path)
+}
+
+check_uses_github_actions <- function() {
+  if (uses_github_actions()) {
+    return(invisible())
+  }
+
+  ui_stop("
+    Cannot detect that package {ui_value(project_name())} already \\
+    uses GitHub Actions.
+    Do you need to run {ui_code('use_github_actions()')}?")
+}
+
+latest_release <- function(repo_spec = "https://github.com/r-lib/actions") {
+  parsed <- parse_repo_url(repo_spec)
+  # https://docs.github.com/en/rest/reference/releases#list-releases
+  raw_releases <- gh::gh(
+    "/repos/{owner}/{repo}/releases",
+    owner       = spec_owner(parsed$repo_spec),
+    repo        = spec_repo(parsed$repo_spec),
+    .api_url    = parsed$host,
+    .limit = Inf
+  )
+  tag_names <- purrr::discard(
+    map_chr(raw_releases, "tag_name"),
+    map_lgl(raw_releases, "prerelease")
+  )
+  pick_tag(tag_names)
+}
+
+# 1) filter to releases in the latest major version series
+# 2) return the max, according to R's numeric_version logic
+pick_tag <- function(nm) {
+  dat <- data.frame(nm = nm, stringsAsFactors = FALSE)
+  dat$version <- numeric_version(sub("^[^0-9]*", "", dat$nm))
+  dat <- dat[dat$version == max(dat$version), ]
+  dat$nm[1]
+}
