@@ -4,7 +4,7 @@
 #' `use_github()` takes a local project and:
 #' * Checks that the initial state is good to go:
 #'   - Project is already a Git repo
-#'   - Current branch is the default branch, e.g. `master` or `main`
+#'   - Current branch is the default branch, e.g. `main` or `master`
 #'   - No uncommitted changes
 #'   - No pre-existing `origin` remote
 #' * Creates an associated repo on GitHub
@@ -12,7 +12,7 @@
 #' * Makes an initial push to GitHub
 #' * Calls [use_github_links()], if the project is an R package
 #' * Configures `origin/DEFAULT` to be the upstream branch of the local
-#'   `DEFAULT` branch, e.g. `master` or `main`
+#'   `DEFAULT` branch, e.g. `main` or `master`
 #'
 #' See below for the authentication setup that is necessary for all of this to
 #' work.
@@ -25,6 +25,11 @@
 #'   such that you have permission to create repositories in this
 #'   `organisation`.
 #' @param private If `TRUE`, creates a private repository.
+#' @param visibility Only relevant for organisation-owned repos associated with
+#'   certain GitHub Enterprise products. The special "internal" `visibility`
+#'   grants read permission to all organisation members, i.e. it's intermediate
+#'   between "private" and "public", within GHE. When specified, `visibility`
+#'   takes precedence over `private = TRUE/FALSE`.
 #' @inheritParams git_protocol
 #' @param host GitHub host to target, passed to the `.api_url` argument of
 #'   [gh::gh()]. If unspecified, gh defaults to "https://api.github.com",
@@ -34,11 +39,11 @@
 #'   For a hypothetical GitHub Enterprise instance, either
 #'   "https://github.acme.com/api/v3" or "https://github.acme.com" is
 #'   acceptable.
-#' @param auth_token,credentials \lifecycle{defunct}: No longer consulted now
-#'   that usethis uses the gert package for Git operations, instead of git2r;
-#'   gert relies on the credentials package for auth. The API requests are now
-#'   authorized with the token associated with the `host`, as retrieved by
-#'   [gh::gh_token()].
+#' @param auth_token,credentials `r lifecycle::badge("deprecated")`: No longer
+#'   consulted now that usethis uses the gert package for Git operations,
+#'   instead of git2r; gert relies on the credentials package for auth. The API
+#'   requests are now authorized with the token associated with the `host`, as
+#'   retrieved by [gh::gh_token()].
 #'
 #' @export
 #' @examples
@@ -54,6 +59,7 @@
 #' }
 use_github <- function(organisation = NULL,
                        private = FALSE,
+                       visibility = c("public", "private", "internal"),
                        protocol = git_protocol(),
                        host = NULL,
                        auth_token = deprecated(),
@@ -65,14 +71,36 @@ use_github <- function(organisation = NULL,
     deprecate_warn_credentials("use_github")
   }
 
+  visibility_specified <- !missing(visibility)
+  visibility <- match.arg(visibility)
   check_protocol(protocol)
   check_uses_git()
-  check_default_branch()
+  default_branch <- git_default_branch()
+  check_current_branch(
+    is = default_branch,
+    # glue-ing happens inside check_current_branch(), where `gb` gives the
+    # current branch
+    "Must be on the default branch ({ui_value(is)}), not {ui_value(gb)}."
+  )
   challenge_uncommitted_changes(msg = "
     There are uncommitted changes and we're about to create and push to a new \\
     GitHub repo")
   check_no_origin()
 
+  if (is.null(organisation)) {
+    if (visibility_specified) {
+      ui_stop("
+        The {ui_code('visibility')} setting is only relevant for
+        organisation-owned repos, within the context of certain \\
+        GitHub Enterprise products.")
+    }
+    visibility <- if (private) "private" else "public"
+  }
+
+  if (!is.null(organisation) && !visibility_specified) {
+    visibility <- if (private) "private" else "public"
+  }
+
   whoami <- suppressMessages(gh::gh_whoami(.api_url = host))
   if (is.null(whoami)) {
     ui_stop("
@@ -86,16 +114,16 @@ use_github <- function(organisation = NULL,
     ui_info("Targeting the GitHub host {ui_value(empirical_host)}")
   }
 
-  owner <- organisation %||%  whoami$login
+  owner <- organisation %||% whoami$login
   repo_name <- project_name()
   check_no_github_repo(owner, repo_name, host)
 
-  repo_desc <- project_data()$Title %||% ""
+  repo_desc <- if (is_package()) package_data()$Title %||% "" else ""
   repo_desc <- gsub("\n", " ", repo_desc)
   repo_spec <- glue("{owner}/{repo_name}")
 
-  private_string <- if (private) "private " else ""
-  ui_done("Creating {private_string}GitHub repository {ui_value(repo_spec)}")
+  visibility_string <- if (visibility == "public") "" else glue("{visibility} ")
+  ui_done("Creating {visibility_string}GitHub repository {ui_value(repo_spec)}")
   if (is.null(organisation)) {
     create <- gh::gh(
       "POST /user/repos",
@@ -110,7 +138,10 @@ use_github <- function(organisation = NULL,
       org = organisation,
       name = repo_name,
       description = repo_desc,
-      private = private,
+      visibility = visibility,
+      # this is necessary to set `visibility` in GHE 2.22 (but not in 3.2)
+      # hopefully it's harmless when not needed
+      .accept = "application/vnd.github.nebula-preview+json",
       .api_url = host
     )
   }
@@ -135,7 +166,6 @@ use_github <- function(organisation = NULL,
     )
   }
 
-  default_branch <- git_branch_default()
   repo <- git_repo()
   remref <- glue("origin/{default_branch}")
   ui_done("
@@ -176,9 +206,9 @@ use_github <- function(organisation = NULL,
 #'   an interactive session, the user can confirm which repo to use for the
 #'   links. In a noninteractive session, links are formed using `upstream`.
 #'
-#' @param host,auth_token \lifecycle{defunct}: No longer consulted now that
-#'   usethis consults the current project's GitHub remotes to get the `host` and
-#'   then relies on gh to discover an appropriate token.
+#' @param host,auth_token `r lifecycle::badge("deprecated")`: No longer consulted
+#'   now that usethis consults the current project's GitHub remotes to get the
+#'   `host` and then relies on gh to discover an appropriate token.
 #' @param overwrite By default, `use_github_links()` will not overwrite existing
 #'   fields. Set to `TRUE` to overwrite existing links.
 #' @export
