@@ -6,6 +6,14 @@ test_that("use_tibble() requires a package", {
 test_that("use_tibble() Imports tibble", {
   create_local_package(path_temp("mypackage"))
   withr::local_options(list(usethis.quiet = FALSE))
-  expect_snapshot(use_tibble())
+  ui_silence(use_package_doc())
+
+  with_mock(
+    check_installed = function(pkg) TRUE,
+    roxygen_update_ns = function(...) NULL,
+    check_functions_exist = function(...) TRUE,
+    expect_snapshot(use_tibble())
+  )
+
   expect_match(desc::desc_get("Imports", proj_get()), "tibble")
 })
